<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="hr">
<context>
    <name>AddonsPage</name>
    <message>
        <location filename="../qml/AddonsPage.qml" line="20"/>
        <source>Add-ons</source>
        <translation>Dodaci</translation>
    </message>
</context>
<context>
    <name>AdvancedSettingsModule</name>
    <message>
        <location filename="../qml/AdvancedSettingsModule.qml" line="15"/>
        <source>Advanced Settings</source>
        <translation>Napredne postavke</translation>
    </message>
    <message>
        <location filename="../qml/AdvancedSettingsModule.qml" line="41"/>
        <source>&quot;Advanced Settings&quot; is only valid for the input method that uses the system settings, if the input method has its own settings, its own settings shall prevail.</source>
        <translation>&quot;Napredne postavke&quot; važe samo za unapred definirane postavke metoda unosa, ako metoda unosa ima svoje postavke, one će prevladati.</translation>
    </message>
    <message>
        <location filename="../qml/AdvancedSettingsModule.qml" line="54"/>
        <source>Global Config</source>
        <translation>Globalne postavke</translation>
    </message>
    <message>
        <location filename="../qml/AdvancedSettingsModule.qml" line="70"/>
        <source>Add-ons</source>
        <translation>Dodaci</translation>
    </message>
    <message>
        <location filename="../qml/AdvancedSettingsModule.qml" line="81"/>
        <source>Keyboard layout</source>
        <translation>Raspored tipkovnice</translation>
    </message>
</context>
<context>
    <name>DetailConfigItem</name>
    <message>
        <location filename="../qml/DetailConfigItem.qml" line="151"/>
        <source>Please enter a new shortcut</source>
        <translation>Molimo unesite novi skraćenica</translation>
    </message>
</context>
<context>
    <name>IMList</name>
    <message>
        <location filename="../qml/IMList.qml" line="152"/>
        <source>Move Up</source>
        <translation>Premjesti gore</translation>
    </message>
    <message>
        <location filename="../qml/IMList.qml" line="160"/>
        <source>Move Down</source>
        <translation>Premjesti dolje</translation>
    </message>
    <message>
        <location filename="../qml/IMList.qml" line="168"/>
        <source>Settings</source>
        <translation>Postavke</translation>
    </message>
    <message>
        <location filename="../qml/IMList.qml" line="176"/>
        <source>Remove</source>
        <translation>Ukloni</translation>
    </message>
</context>
<context>
    <name>InputMethodsChooser</name>
    <message>
        <location filename="../qml/InputMethodsChooser.qml" line="35"/>
        <source>Add input method</source>
        <translation>Dodaj metodu unosa</translation>
    </message>
    <message>
        <location filename="../qml/InputMethodsChooser.qml" line="41"/>
        <source>Search</source>
        <translation>Traži</translation>
    </message>
    <message>
        <location filename="../qml/InputMethodsChooser.qml" line="109"/>
        <source>Find more in App Store</source>
        <translation>Pronađite više u Apple Store-u</translation>
    </message>
    <message>
        <location filename="../qml/InputMethodsChooser.qml" line="129"/>
        <source>Cancel</source>
        <translation>Odustani</translation>
    </message>
    <message>
        <location filename="../qml/InputMethodsChooser.qml" line="136"/>
        <source>Add</source>
        <translation>Dodaj</translation>
    </message>
</context>
<context>
    <name>KeyboardLayout</name>
    <message>
        <location filename="../qml/KeyboardLayout.qml" line="16"/>
        <source>Keyboard layout</source>
        <translation>Raspored tipkovnice</translation>
    </message>
    <message>
        <location filename="../qml/KeyboardLayout.qml" line="34"/>
        <source>done</source>
        <translation>gotovo</translation>
    </message>
    <message>
        <location filename="../qml/KeyboardLayout.qml" line="34"/>
        <source>edit</source>
        <translation>uredi</translation>
    </message>
    <message>
        <location filename="../qml/KeyboardLayout.qml" line="57"/>
        <source>Add the corresponding input method in &lt;a style=&apos;text-decoration: none;&apos; href=&apos;Manage Input Methods&apos;&gt;Input Method Management&lt;/a&gt; to ensure the keyboard layout works when added or switched.</source>
        <translation>Dodaj odgovarajuću metodu unosa u &lt;a style=&apos;text-decoration: none;&apos; href=&apos;Manage Input Methods&apos;&gt;Upravljanje metodama unosa&lt;/a&gt; kako bi se osiguralo da raspored tipkovnice radi kada se dodaje ili mijenja.</translation>
    </message>
    <message>
        <location filename="../qml/KeyboardLayout.qml" line="142"/>
        <source>Add new keyboard layout...</source>
        <translation>Dodaj novi raspored tipkovnice...</translation>
    </message>
</context>
<context>
    <name>KeyboardLayoutModule</name>
    <message>
        <location filename="../qml/KeyboardLayoutModule.qml" line="16"/>
        <source>Keyboard layout</source>
        <translation>Raspored tipkovnice</translation>
    </message>
    <message>
        <location filename="../qml/KeyboardLayoutModule.qml" line="34"/>
        <source>done</source>
        <translation>gotovo</translation>
    </message>
    <message>
        <location filename="../qml/KeyboardLayoutModule.qml" line="34"/>
        <source>edit</source>
        <translation>uredi</translation>
    </message>
    <message>
        <location filename="../qml/KeyboardLayoutModule.qml" line="57"/>
        <source>Add the corresponding input method in &lt;a style=&apos;text-decoration: none;&apos; href=&apos;Manage Input Methods&apos;&gt;Input Method Management&lt;/a&gt; to ensure the keyboard layout works when added or switched.</source>
        <translation>Dodaj odgovarajuću metodu unosa u &lt;a style=&apos;text-decoration: none;&apos; href=&apos;Manage Input Methods&apos;&gt;Upravljanje metodama unosa&lt;/a&gt; kako bi se osiguralo da raspored tipkovnice radi kada se dodaje ili mijenja.</translation>
    </message>
    <message>
        <location filename="../qml/KeyboardLayoutModule.qml" line="140"/>
        <source>Add new keyboard layout...</source>
        <translation>Dodaj novi raspored tipkovnice...</translation>
    </message>
</context>
<context>
    <name>LayoutsChooser</name>
    <message>
        <location filename="../qml/LayoutsChooser.qml" line="30"/>
        <source>Add new keyboard layout</source>
        <translation>Dodaj novi raspored tipkovnice</translation>
    </message>
    <message>
        <location filename="../qml/LayoutsChooser.qml" line="38"/>
        <source>Search</source>
        <translation>Traži</translation>
    </message>
    <message>
        <location filename="../qml/LayoutsChooser.qml" line="67"/>
        <source>Current language keyboard layouts</source>
        <translation>Trenutni jezikovi rasporedi tipkovnice</translation>
    </message>
    <message>
        <location filename="../qml/LayoutsChooser.qml" line="90"/>
        <source>Cancel</source>
            <translation>Odustani</translation>
    </message>
    <message>
        <location filename="../qml/LayoutsChooser.qml" line="97"/>
        <source>Add</source>
        <translation>Dodaj</translation>
    </message>
</context>
<context>
    <name>ManageInputMethodsModule</name>
    <message>
        <location filename="../qml/ManageInputMethodsModule.qml" line="15"/>
        <source>Input method management</source>
        <translation>Upravljanje metodama unosa</translation>
    </message>
    <message>
        <location filename="../qml/ManageInputMethodsModule.qml" line="33"/>
        <source>Add input method</source>
        <translation>Dodaj metodu unosa</translation>
    </message>
</context>
<context>
    <name>ShortcutsModule</name>
    <message>
        <location filename="../qml/ShortcutsModule.qml" line="12"/>
        <location filename="../qml/ShortcutsModule.qml" line="14"/>
        <location filename="../qml/ShortcutsModule.qml" line="151"/>
        <location filename="../qml/ShortcutsModule.qml" line="152"/>
        <source>None</source>
        <translation>Nijedan</translation>
    </message>
    <message>
        <location filename="../qml/ShortcutsModule.qml" line="119"/>
        <source>Shortcuts</source>
        <translation>Skraćenice</translation>
    </message>
    <message>
        <location filename="../qml/ShortcutsModule.qml" line="134"/>
        <source>Restore Defaults</source>
        <translation>Vrati zadane postavke</translation>
    </message>
    <message>
        <location filename="../qml/ShortcutsModule.qml" line="200"/>
        <source>Scroll between input methods</source>
        <translation>Scrollanje između metoda unosa</translation>
    </message>
    <message>
        <location filename="../qml/ShortcutsModule.qml" line="230"/>
        <source>Turn on or off input methods</source>
        <translation>Uključivanje ili isključivanje metoda unosa</translation>
    </message>
    <message>
        <location filename="../qml/ShortcutsModule.qml" line="273"/>
        <source>It turns on or off the currently used input method.If no input method is being used or the first input method is not the keyboard, it switches between the first input method and the currently used keyboard/input method.</source>
        <translation>Uključuje ili isključuje trenutno korišteni metod unosa. Ako nije korišten niti jedan metod unosa ili je prvi metod unosa različit od tastature, prebacuje se između prvog metoda unosa i trenutno korištenog metoda unosa/tastature.</translation>
    </message>
</context>
<context>
    <name>dcc::Locale::dialectNames</name>
    <message>
        <location filename="../keyboard-layout/operation/dcclocale.cpp" line="62"/>
        <source>Traditional Chinese (Chinese Hong Kong)</source>
        <translation>Tradicionalna kineska (Kina Hong Kong)</translation>
    </message>
    <message>
        <location filename="../keyboard-layout/operation/dcclocale.cpp" line="65"/>
        <source>Traditional Chinese (Chinese Taiwan)</source>
        <translation>Tradicionalna kineska (Kina Tajvan)</translation>
    </message>
</context>
<context>
    <name>dcc::Locale::regionNames</name>
    <message>
        <location filename="../keyboard-layout/operation/dcclocale.cpp" line="86"/>
        <source>Taiwan China</source>
        <translation>Tajvan Kina</translation>
    </message>
</context>
<context>
    <name>dccV25::KeyboardController</name>
    <message>
        <location filename="../keyboard-layout/operation/keyboardcontroller.cpp" line="55"/>
        <source>This shortcut conflicts with [%1]</source>
            <translation>Ova skraćenica se konfliktira s [%1]</translation>
    </message>
</context>
<context>
    <name>dccV25::ShortcutModel</name>
    <message>
        <location filename="../keyboard-layout/operation/shortcutmodel.cpp" line="248"/>
        <source>System</source>
        <translation>Sustav</translation>
    </message>
    <message>
        <location filename="../keyboard-layout/operation/shortcutmodel.cpp" line="253"/>
        <source>Window</source>
        <translation>Prozor</translation>
    </message>
    <message>
        <location filename="../keyboard-layout/operation/shortcutmodel.cpp" line="258"/>
        <source>Workspace</source>
        <translation>Radni prostor</translation>
    </message>
    <message>
        <location filename="../keyboard-layout/operation/shortcutmodel.cpp" line="263"/>
        <source>AssistiveTools</source>
        <translation>Pomoćne alate</translation>
    </message>
    <message>
        <location filename="../keyboard-layout/operation/shortcutmodel.cpp" line="268"/>
        <location filename="../keyboard-layout/operation/shortcutmodel.cpp" line="339"/>
        <source>Custom</source>
        <translation>Prilagođeno</translation>
    </message>
    <message>
        <location filename="../keyboard-layout/operation/shortcutmodel.cpp" line="394"/>
        <source>None</source>
        <translation>Nijedan</translation>
    </message>
</context>
<context>
    <name>fcitx5configtool</name>
    <message>
        <location filename="../qml/fcitx5configtool.qml" line="8"/>
        <source>Input Methods</source>
        <translation>Metodi unosa</translation>
    </message>
    <message>
        <location filename="../qml/fcitx5configtool.qml" line="9"/>
        <source>Input method management, input method shortcuts, advanced settings</source>
        <translation>Upravljanje metodama unosa, skraćenice metoda unosa, napredne postavke</translation>
    </message>
</context>
</TS>